
source ../../bash_utils/helpers.sh

usage() {
    info "USAGE:"
    info "--repo [--branch] [--bundle-env] [--mn5-dir] [--mn5-def]"
    info "--help [--force] [--name] [--install]"
    info "name : Set name for the installation"
    info "force : no ask for sync files"
    info "mn5-dir : Path to be used with rsync (mn5-def: mn5-transfer1:/gpfs/scratch/bsc32/bsc032756/AUTO_APPS)"
}

parse_args() {
    OPTIONS=$(getopt -o "" --long repo:,branch:,bundle-env:,mn5-dir:,mn5-def,name:,force,help,install -n "$0" -- "$@")
    eval set -- "$OPTIONS"

    while true; do
        case "$1" in
            --repo)
                IFS_BUNDLE_REPO="$2"
                shift 2
            ;;
            --branch)
                IFS_BUNDLE_BRANCH="$2"
                GIT_BRANCH="-b $2"
                shift 2
            ;;
            --bundle-env)
                IFS_BUNDLE_ENV=$2
                shift 2
            ;;
            --mn5-dir)
                MN5_SOURCE_PATH="$2"
                shift 2
            ;;
            --mn5-def)
                MN5_SOURCE_PATH="mn5-transfer1:/gpfs/scratch/bsc32/bsc032756/AUTO_APPS"
                shift
            ;;
            --force)
                FORCE=true
                shift
            ;;
            --env)
                ENV_FILE="$2"
                shift 2
            ;;
            --name)
                INSTALL_NAME=$2
                shift 2
            ;;
            --install)
                INSTALL=true
                shift
            --help)
                usage
                exit 0
            ;;
            --)
                shift
                break
            ;;
            *)
                usage
                exit 1
            ;;
        esac
    done
}

check_required_args(){
    [ -z $IFS_BUNDLE_REPO ] && fatal "Must set repo with --repo"
}

print_options(){
    info "===============================IFS-BUNDLE==========================================="
    info "REPO: $IFS_BUNDLE_REPO"
    [ -z "$IFS_BUNDLE_BRANCH" ] && info "BRANCH: Default branch for ifs-bundle"
    [ -z "$IFS_BUNDLE_BRANCH" ] || info "BRANCH: $IFS_BUNDLE_BRANCH"
    [ -z $IFS_BUNDLE_ENV ] && info "IFS-BUNDLE-ENV: NO OVERRIDE" 
    [ -z $IFS_BUNDLE_ENV ] || info "IFS-BUNDLE-ENV: $IFS_BUNDLE_ENV"
    [ -z $MN5_SOURCE_PATH ] && info "MN5_PATH: Disable copy"
    [ -z $MN5_SOURCE_PATH ] || info "MN5_PATH: $MN5_SOURCE_PATH"
    [ -z $INSTALL_NAME ] || info "FOLDER: $INSTALL_NAME"
    [ -z $INSTALL_NAME ] && info "USING BRANCH HASH AS INSTALLATION NAME"
    info "===================================================================================="

    if [ $FORCE = false ]; then
        echo -n "CONTINUE? (Y/N) "
        read ANSWER
        case "$ANSWER" in
            [Yy])
                success "OK"
                ;;
            *)
                fatal "USER INPUT: $ANSWER"
                ;;
        esac
    else
        info "Force ENABLED, skip ask to the user"
    fi
}
