#!/bin/bash

source ../../bash_utils/helpers.sh

if [[ $# -ne 3 ]]; then
    info "Usage: $0 <source (tar or tar.gz)> <install_dir> <running_method>"
    info "OPTIONAL: <arch_setup> (otherwise it will use the mn5-gpp default)"
    info "arch setup: path like arch/eurohpc/mn5-gpp/default"
    info "running method: interactive | mn5_queue (see bsc_queues command)"
    exit 1
fi

UTILS_DIR=$(pwd -P)
SOURCE_FILE=$1
INSTALL_DIR=$2
RUN_METHOD=$3
ARCH_SETUP="arch/eurohpc/mn5-gpp/default"
[ -z $4 ] && ARCH_SETUP=$4

# 1. Check install dir:
info "Checking installation dir... "
if [ ! -d "$INSTALL_DIR" ]; then
    info "Install dir not found. Creating"
    mkdir -p $INSTALL_DIR
fi
success "DONE"
cd $INSTALL_DIR

# 2. Uncompress sources:
info "Uncompressing sources into $INSTALL_DIR DIR... "
if [ ! -f $SOURCE_FILE ]; then
    fatal "Unable to find ${SOURCE_FILE}."
fi
if [ -d "source" ]; then
    info "Found source folder, SKIPPING"
else
    if [[ "$SOURCE_FILE" == *.tar ]]; then
        tar -xf $SOURCE_FILE
    elif [[ "$SOURCE_FILE" == *.tar.gz ]]; then
        tar -xzf $SOURCE_FILE
    else
        fatal "Unrecognized file type: $SOURCE_FILE"
        success "DONE"
    fi
fi

# 2. Check arch_file presence
[ -d $ARCH_SETUP ] || fatal "Unable to find ${ARCH_SETUP}. $(ls -la arch)"

# 3. Submit compilation script:

case "$RUN_METHOD" in
    interactive)
        info "Running compilation in ${INSTALL_DIR}"
        bash ${UTILS_DIR}/compile-mn5-gpp.slurm ${INSTALL_DIR} ${ARCH_SETUP}
    ;;
    *)
        info "Submitting compilation into $RUN_METHOD queue"
        sbatch  --qos=${RUN_METHOD} \
                ${UTILS_DIR}/compile-mn5-gpp.slurm ${INSTALL_DIR} ${ARCH_SETUP}
    ;;
esac
